Stan Math Library: stan/math/mix/mat/functor/grad_tr_mat_times_hessian.hpp File Reference

| Stan Math Library 2.10.0 reverse mode automatic differentiation

- Main Page
- Modules
- Namespaces
- Classes
- Files

- File List
- File Members

Namespaces | Functions
grad_tr_mat_times_hessian.hpp File Reference
`#include <stan/math/fwd/core.hpp>`
`#include <stan/math/prim/mat/fun/Eigen.hpp>`
`#include <stan/math/rev/core.hpp>`
`#include <stan/math/mix/mat/functor/gradient_dot_vector.hpp>`
`#include <stdexcept>`
`#include <vector>`

Go to the source code of this file.

## Namespaces
| stan
| stan::math
| Matrices and templated mathematical functions.

## Functions
template<typename F >
void | stan::math::grad_tr_mat_times_hessian (const F &f, const Eigen::Matrix< double, Eigen::Dynamic, 1 > &x, const Eigen::Matrix< double, Eigen::Dynamic, Eigen::Dynamic > &M, Eigen::Matrix< double, Eigen::Dynamic, 1 > &grad_tr_MH)

[ Stan Home Page ] © 2011–2016, Stan Development Team.